# Lupv - Lup Viewer

[![image](https://img.shields.io/pypi/v/lupv.svg)](https://pypi.org/project/requests/)
[![image](https://img.shields.io/pypi/l/lupv.svg)](https://pypi.org/project/requests/)
[![image](https://img.shields.io/pypi/pyversions/lupv.svg)](https://pypi.org/project/requests/)

## Screeenshot

![lupv-thumb](/uploads/3a3936a39b6bd6eedfe3b2bba6ebbaae/lupv-thumb.png)

## Requirements

See [requirements.txt](requirements.txt)

## Platform

- GNU/Linux

## Installation

- Use binaries from releases tag.

## Usage

- You can watch the screencast [here](https://youtu.be/gY7bVipbd_w)

## License

GPLv3




